@@ -1,5 +1,6 @@
 """Template tags for the ``enquiry`` app."""
 from django import template
+from django.db.models import Q
 from django.utils.timezone import now
 
 from enquiry.models import Enquiry
@@ -11,11 +12,11 @@ register = template.Library()
 def render_current_poll(context):
     """Template tag to render one of the current active polls."""
     enquiries = Enquiry.objects.filter(
-        start_date__lt=now(), end_date__gt=now())
+        Q(start_date__lt=now()),
+        Q(end_date__gt=now()) | Q(end_date__isnull=True))
     if enquiries:
-        translation = enquiries[0].get_translation()
         return {
-            'enquiry_translated': translation,
+            'enquiry': enquiries[0],
             'has_voted': enquiries[0].has_voted(context['request'])
         }
     return ''
@@ -25,7 +26,8 @@ def render_current_poll(context):
 def get_current_poll():
     """Returns the current active poll."""
     enquiries = Enquiry.objects.filter(
-        start_date__lt=now(), end_date__gt=now())
+        Q(start_date__lt=now()),
+        Q(end_date__gt=now()) | Q(end_date__isnull=True))
     if enquiries:
         return enquiries[0]
     return None
